BOOST_PP_LIMIT_REPEAT

The BOOST_PP_LIMIT_REPEAT macro defines the maximum number of repetitions supported by each BOOST_PP_REPEAT dimension.

#### Usage

BOOST_PP_LIMIT_REPEAT

#### Remarks

This macro current expands to 256.

#### Requirements

Header: <boost/preprocessor/config/limits.hpp>

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)